#
# ovirt-hosted-engine-setup -- ovirt hosted engine setup
# Copyright (C) 2013-2018 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#

%global         package_version 2.4.8
%global         ovirt_hosted_engine_setup_templates %{_datadir}/%{name}/templates
%global         ovirt_hosted_engine_setup_scripts %{_datadir}/%{name}/scripts
%global         vdsmhooksdir %{_libexecdir}/vdsm/hooks

# {Downstream only
%define enable_autotools 1
# }

%if 0%{?fedora} >= 30 || 0%{?rhel} >= 8
%global     python_interpreter %{__python3}
%global     python_target_version python3
%global     python_sitelib %{python3_sitelib}
%else
%global     python_interpreter %{__python2}
%global     python_target_version python2
%global     python_sitelib %{python2_sitelib}
%endif



Summary:        oVirt Hosted Engine setup tool
Name:           ovirt-hosted-engine-setup
Version:        2.4.8
Release:        1%{?release_suffix}%{?dist}
License:        LGPLv2+
URL:            http://www.ovirt.org
Source0:        http://resources.ovirt.org/pub/src/%{name}/%{name}-%{package_version}.tar.gz
Source1:        readme.appliance
Source2:        readme.rollback
Group:          Applications/System

BuildArch:      noarch

# Python dependencies

Requires:       %{python_target_version}

%if %{python_target_version} == python2
Requires:       python-ethtool >= 0.6-3
Requires:       python-ovirt-engine-sdk4 >= 4.3.1
Requires:       sanlock-python
Requires:       libselinux-python
%else
Requires:       %{python_target_version}-ethtool >= 0.6-3
Requires:       %{python_target_version}-ovirt-engine-sdk4 >= 4.3.1
Requires:       %{python_target_version}-sanlock
Requires:       %{python_target_version}-libselinux
%endif

Requires:       %{python_target_version}-dateutil
Requires:       %{python_target_version}-netaddr
Requires:       %{python_target_version}-otopi >= 1.9.0
Requires:       %{python_target_version}-ovirt-setup-lib >= 1.3.2
Requires:       %{python_target_version}-six

BuildRequires:  %{python_target_version}-devel
BuildRequires:  %{python_target_version}-pytest

# Non Python dependencies
Requires:       bind-utils
Requires:       genisoimage
Requires:       lsof
Requires:       openssh-server
Requires:       openssl
Requires:       sanlock >= 2.8
Requires:       sudo
Requires:       libvirt-client
Requires:       virt-install
Requires:       ansible = 2.9.14
# default libvirt network
Requires:       libvirt-daemon-config-network

BuildRequires:  gettext >= 0.18.2

%if 0%{?enable_autotools}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-devel
%endif

%if 0%{?fedora}
Requires:       qemu-img
%endif

%if 0%{?rhel}
%if 0%{?rhel} >= 8
%if 0%{?centos}
Requires:       qemu-img
%else
Requires:       qemu-img >= 15:3.1.0-20.module+el8+2888+cdc893a8
%endif #centos
%else
Requires:       qemu-img-rhev
%endif #rhel >= 8
%endif #rhel


Requires:       ovirt-hosted-engine-ha >= 2.4
Requires:       glusterfs-cli >= 5.6
Requires:       vdsm-python >= 4.40.0
Requires(post): vdsm-python >= 4.40.0
Requires:       ovirt-host >= 4.4.0
Requires:       ovirt-ansible-collection >= 1.2.0

# Conflicts:      ovirt-engine-appliance < 4.4
# Conflicts:      ovirt-engine-appliance >= 4.5

# { Downstream only
Conflicts:      rhvm-appliance < 2:4.4
Conflicts:      rhvm-appliance >= 2:4.5

Patch1: 0001-packaging-branding-for-ovirt-hosted-engine-setup.patch
# }

%description
Hosted Engine setup tool for oVirt project.

%prep
%setup -q -n %{name}-%{package_version}
%patch1 -p1
cp %{SOURCE1} %{SOURCE2} .

%build
%if 0%{?enable_autotools}
autoreconf -ivf
%endif
%configure \
        --docdir="%{_docdir}/%{name}-%{version}" \
        --disable-python-syntax-check \
        %{?conf}
make %{?_smp_mflags}

%check
make test

%install
make %{?_smp_mflags} install DESTDIR="%{buildroot}"
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc README
%doc readme.appliance
%doc readme.rollback
%dir %{_sysconfdir}/ovirt-hosted-engine-setup.env.d
%dir %{_sysconfdir}/ovirt-hosted-engine
%ghost %attr(600, root, root) %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
%dir %attr(700, root, root) %{_localstatedir}/log/ovirt-hosted-engine-setup
%dir %{_localstatedir}/lib/ovirt-hosted-engine-setup
%dir %{_localstatedir}/lib/ovirt-hosted-engine-setup/answers
%{_sbindir}/hosted-engine
%{_sbindir}/ovirt-hosted-engine-setup
%{_sbindir}/ovirt-hosted-engine-cleanup
%{python_sitelib}/ovirt_hosted_engine_setup/
%{_datadir}/%{name}/
%{_mandir}/man8/*

#move to a separate package?
%{vdsmhooksdir}/before_vm_start/

%post
touch %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
chmod 600 %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
%{python_interpreter} -c '
from vdsm.tool.configurators import passwd
print((
    "[credentials-vdsm]\n"
    "authname={authname}\n"
    "password={password}\n\n"
    "[auth-libvirt-localhost]\n"
    "credentials=vdsm\n"
).format(
    authname=passwd.SASL_USERNAME,
    password=passwd.libvirt_password(),
))
' > %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf

%changelog
* Wed Oct 28 2020 Asaf Rachmani <arachman@redhat.com> - 2.4.8-1
- Release

* Thu Oct 15 2020 Asaf Rachmani <arachman@redhat.com> - 2.4.7-3
- Release
- Require ansible 2.9.14

* Tue Oct 06 2020 Asaf Rachmani <arachman@redhat.com> - 2.4.7-2
- Release
- Require ovirt-ansible-collection

* Tue Sep 01 2020 Asaf Rachmani <arachman@redhat.com> - 2.4.6-2
- Release

* Mon Aug 10 2020 Asaf Rachmani <arachman@redhat.com> - 2.4.6-1
- Release

* Tue Jun 09 2020 Asaf Rachmani <arachman@redhat.com> - 2.4.5-1
- Release

* Mon Mar 23 2020 Asaf Rachmani <arachman@redhat.com> - 2.4.4-1
- Release

* Tue Mar 10 2020 Evgeny Slutsky <eslutsky@redhat.com> - 2.4.3-1
- Release

* Tue Feb 25 2020 Sandro Bonazzola <sbonazzo@redhat.com> - 2.4.2-2
- fix dependencies aligining to upstream spec file

* Tue Feb 25 2020 - Evgeny Slutsky <eslutsky@redhat.com> - 2.4.2-1
- Release

* Wed Feb 05 2020 - Yedidyah Bar David <didi@redhat.com> - 2.4.1-1
- Release

* Mon Nov 25 2019 Evgeny Slutsky <eslutsky@redhat.com> - 2.4.0-1
- Rebase on upstream 2.4.0

